<%@ page import="jetbrains.buildServer.maven.web.CreateMavenBuildTypeForm" %>
<%@ page import="jetbrains.buildServer.serverSide.crypt.RSACipher" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core"%>
<%@ include file="/include-internal.jsp" %>
<%@ taglib prefix="admin" tagdir="/WEB-INF/tags/admin" %>

<jsp:useBean id="project" type="jetbrains.buildServer.serverSide.SProject" scope="request"/>
<jsp:useBean id="serverSummary" type="jetbrains.buildServer.web.openapi.ServerSummary" scope="request"/>
<c:set var="title" value="Create Maven build configuration" scope="request"/>
<bs:page>
<jsp:attribute name="head_include">
  <bs:linkCSS>
    /css/project.css
    /css/admin/adminMain.css
    /css/admin/projectForm.css
    /css/admin/vcsRootsTable.css
    /css/admin/reportTabs.css
  </bs:linkCSS>
  <style type="text/css">
    td.name, th.name {
      width: 50%;
    }
    .runnerFormTable label {
      width: 8em;
    }

    .runnerFormTable th {
      width: 15%;
    }
  </style>
  <bs:linkScript>
    /js/bs/blocks.js
    /js/bs/blocksWithHeader.js
    /js/bs/copyProject.js
    /js/bs/moveBuildType.js
    /js/bs/editProject.js
    /js/bs/testConnection.js
    /js/bs/reportTabs.js
  </bs:linkScript>
  <script type="text/javascript">
    BS.Navigation.items = [
    {title: "Administration", url: '<c:url value="/admin/admin.html"/>'},
    {title: '<bs:escapeForJs text="${project.name} Project"/>', url: '<admin:editProjectLink withoutLink="true" projectId="${project.projectId}"/>'},
    {title: '<bs:escapeForJs text="${title}" forHTMLAttribute="true"/>', selected:true}
      ];

    document.observe("dom:loaded", function() {
      if ($('url')) $('url').focus();
    });

    function encryptPassword() {
      $('encryptedPassword').value = BS.Encrypt.encryptData($('password1').value, $('publicKey').value);
      $('password1').value = "";
    }
  </script>
</jsp:attribute>

<jsp:attribute name="quickLinks_include">
    <bs:projectLink project="${project}" style="float:left;">Project Home</bs:projectLink>
</jsp:attribute>

<jsp:attribute name="body_include">

<bs:professionalLimited shouldBePositive="${serverSummary.buildConfigurationsLeft}">
<jsp:attribute name="disabled">
  <div class="attentionComment">
    You cannot create another build configuration, because TeamCity Professional only allows maximum of
    <strong>${serverSummary.licensingPolicy.maxNumberOfBuildTypes}</strong> build configurations.<bs:help file="TeamCity+Editions"/>
  </div>
</jsp:attribute>

<jsp:body>
<c:set var="URL_ERROR" value="<%=CreateMavenBuildTypeForm.URL_ERROR%>"/>
<c:set var="GENERAL_ERROR" value="<%=CreateMavenBuildTypeForm.GENERAL_ERROR%>"/>
<c:set var="FILE_ERROR" value="<%=CreateMavenBuildTypeForm.FILE_ERROR%>"/>
  
<jsp:useBean id="form" type="jetbrains.buildServer.maven.web.CreateMavenBuildTypeForm" scope="request"/>
<jsp:useBean id="availableVcs" type="java.util.Collection<java.lang.String>" scope="request"/>

<div id="container" style="width: 70%">
<c:url var="actionUrl" value="/admin/createMavenBuildType.html"/>
<form action="${actionUrl}" enctype="multipart/form-data" method="post" autocomplete="off" onsubmit="encryptPassword(); return true;">
  <span class="error" id="errorGeneral">${form.errors[GENERAL_ERROR]}</span>

  <table class="runnerFormTable">
    <tr>
      <th><label for="url">POM file: <l:star/></label></th>
      <td>
        <div>
          <forms:textField name="url" style="width:40em;" maxlength="255" className="${empty form.errors[URL_ERROR] ? 'textfield' : 'textfield errorField'}" value="${form.url}"/>
          <span class="error" id="errorUrl">${form.errors[URL_ERROR]}</span>
          <span class="smallNote">
          Specify a regular URL (like http:, ftp:, file:, etc.)
          </span>
          <span class="smallNote">
             or a URL in <em>Maven SCM URL format</em><bs:help file="Creating+and+Editing+Build+Configurations" anchor="MavenSCMURLformat"/>. Supported version control systems:
            <c:forEach var="vcsName" items="${availableVcs}" varStatus="status"><c:out value="${vcsName}"/><c:if test="${not status.last}">, </c:if></c:forEach>
          </span>
        </div>
        <br/>
        <div>
          <input type=file name="pomFile" style="width:40em;" maxlength="255"/>
          <span class="error" id="errorFile">${form.errors[FILE_ERROR]}</span>
          <span class="smallNote">
          ...or upload a POM file.
          </span>
        </div>
      </td>
    <tr>
      <th><label for="username1">Username:</label></th>
      <td>
        <forms:textField name="username1" style="width:20em;" maxlength="255" value="${form.username1}"/>
      </td>
    </tr>
    <tr>
      <th><label for="password1">Password:</label></th>
      <td>
        <forms:passwordField name="password1" style="width:20em;" maxlength="255"/>
      </td>
    </tr>
    <tr>
      <th class="noBorder"><label for="goals">Goals:</label></th>
      <td class="noBorder">
        <forms:textField name="goals" style="width:20em;" maxlength="255" value="${form.goals}"/>
        <span class="error" id="errorGoals"></span>
      </td>
    </tr>
    <tr>
      <th class="noBorder">Triggering:</th>
      <td class="noBorder">
        <forms:checkbox name="enableSnapshotTrigger" checked="${form.enableSnapshotTrigger}"/>
        <label for="enableSnapshotTrigger">Trigger a build whenever a SNAPSHOT dependency artifact is updated</label>
      </td>
    </tr>
  </table>

  <div class="saveButtonsBlock">
  <forms:cancel href="<admin:editProjectLink withoutLink='true' projectId='${project.projectId}'/>"/>
  <forms:submit id="createMavenBuildType" name="submitCreateMavenBuildType" label="Create"/>
  <forms:saving/>
  </div>

  <input type="hidden" id="encryptedPassword" name="encryptedPassword" value=""/>
  <input type="hidden" name="projectId" value="${project.projectId}"/>
  <c:set var="publicKey" value="<%=RSACipher.getHexEncodedPublicKey()%>"/>
  <input type="hidden" name="publicKey" id="publicKey" value="${publicKey}"/>
</form>
</div>
</jsp:body>
</bs:professionalLimited>
</jsp:attribute>

</bs:page>
