<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib prefix="props" tagdir="/WEB-INF/tags/props" %>
<%@ taglib prefix="bs" tagdir="/WEB-INF/tags" %>
<%@ taglib prefix="l" tagdir="/WEB-INF/tags/layout" %>
<%@ taglib prefix="forms" tagdir="/WEB-INF/tags/forms" %>
<%@ taglib prefix="authz" tagdir="/WEB-INF/tags/authz"%>
<%@include file="mavenConsts.jsp"%>

<jsp:useBean id="propertiesBean" scope="request" type="jetbrains.buildServer.controllers.BasePropertiesBean"/>
<tr>
  <th><label for="goals">Goals:</label></th>
  <td>
    <props:textProperty name="goals" className="longField"/>
    <span class="error" id="error_goals"></span>
    <span class="smallNote">Space-separated goals to execute.</span></td>
</tr>

<tr>
  <th><label for="pomLocation">Path to POM file:</label></th>
  <td>
    <props:textProperty name="pomLocation" className="longField"/>
    <span class="smallNote">Specified path should be relative to the checkout directory.</span>
    </td>
</tr>

<tr>
  <th><label for="runnerArgs">Additional Maven command line parameters:</label></th>
  <td><props:textProperty name="runnerArgs" className="longField" expandable="true"/>
</tr>

<forms:workingDirectory/>


<l:settingsGroup title="Maven Home">
<tr>
  <th><label for="${MAVEN_SELECTION}">Maven selection:</label></th>
  <td><props:selectProperty name="${MAVEN_SELECTION}" onchange="syncMavenSelectionControlState(); return true;">
    <props:option id="${MAVEN_SELECTION_DEFAULT}" value="${MAVEN_SELECTION_DEFAULT}">&lt;Default&gt;</props:option>
    <props:option id="${MAVEN_SELECTION_CUSTOM}" value="${MAVEN_SELECTION_CUSTOM}">&lt;Custom&gt;</props:option>
    <props:option value="${MAVEN_SELECTION_BUNDLED_M2}">Bundled Maven 2 (${BUNDLED_M2_FULL_VERSION})</props:option>
    <props:option value="${MAVEN_SELECTION_BUNDLED_M3}">Bundled Maven 3 (${BUNDLED_M3_FULL_VERSION})</props:option>
    </props:selectProperty>
    <span class="smallNote">Select Maven installation. By default the path is taken from the M2_HOME environment variable, otherwise the bundled Maven 3 will be used.</span>
  </td>
</tr>
<tr id="${CUSTOM_MAVEN_PATH}_section">
  <th><label for="${CUSTOM_MAVEN_PATH}">Custom path:<bs:help file="Maven2" anchor="mavenMavenHomePathOptionDescription"/></label></th>
  <td>
    <props:textProperty name="${CUSTOM_MAVEN_PATH}" className="longField"/>
    <span class="error" id="error_${CUSTOM_MAVEN_PATH}"></span>
    <span class="smallNote">Provide path to a custom Maven installation. Maven 1.x not supported.</span>
  </td>
</tr>
</l:settingsGroup>

<l:settingsGroup title="User Settings">
<tr>
  <th><label for="${USER_SETTINGS_SELECTION}">User settings selection:</label></th>
  <td>
    <props:selectProperty name="${USER_SETTINGS_SELECTION}" onchange="syncUserSettingsControlState(); return true;">
      <c:set var="currentSettingsItem" value="${propertiesBean.properties[USER_SETTINGS_SELECTION]}" scope="request"/>
      <jsp:include page="/plugins/Maven2/settingsList.html"/>
    </props:selectProperty>
    <span class="error" id="error_${USER_SETTINGS_SELECTION}"></span>
    <span class="smallNote">Select one of the predefined settings files or provide a custom path. By default a standard Maven settings file location is used.</span>
    <span><authz:authorize allPermissions="CHANGE_SERVER_SETTINGS" ><a href="<c:url value='/admin/admin.html?item=mavenSettings'/>">Manage settings files</a>.</authz:authorize></span>
  </td>
</tr>
<tr id="${USER_SETTINGS_PATH}_section">
  <th><label for="${USER_SETTINGS_PATH}">Custom path:</label></th>
  <td>
    <props:textProperty name="${USER_SETTINGS_PATH}" className="longField"/>
    <span class="error" id="error_${USER_SETTINGS_PATH}"></span>
    <span class="smallNote">Enter path to a user settings file.</span>
  </td>
</tr>
</l:settingsGroup>

<l:settingsGroup title="Java Parameters">
<props:editJavaHome/>
<props:editJvmArgs/>
</l:settingsGroup>

<l:settingsGroup title="Local Artifact Repository Settings">
  <tr>
    <th><label for="${USE_OWN_LOCAL_REPO}">Use own local artifact repository:</label></th>
    <td>
      <props:checkboxProperty name="${USE_OWN_LOCAL_REPO}"/><label for="${USE_OWN_LOCAL_REPO}">Use own local repository for this build configuration</label>
    </td>
  </tr>
</l:settingsGroup>

<l:settingsGroup title="Incremental Building">
  <tr>
    <th><label for="${IS_INCREMENTAL}">Enable incremental building:</label></th>
    <td>
      <props:checkboxProperty name="${IS_INCREMENTAL}"/><label for="${IS_INCREMENTAL}">Build only modules affected by changes</label>
    </td>
  </tr>
</l:settingsGroup>

<script type="text/javascript">
  window.syncUserSettingsControlState = function() {
    if($("${USER_SETTINGS_SELECTION_BY_PATH}").selected) {
      BS.Util.show("${USER_SETTINGS_PATH}_section");
    }
    else {
      BS.Util.hide("${USER_SETTINGS_PATH}_section");
    }

    BS.MultilineProperties.updateVisible();
  };

  window.syncMavenSelectionControlState = function() {
    if($("${MAVEN_SELECTION_CUSTOM}").selected) {
      BS.Util.show("${CUSTOM_MAVEN_PATH}_section");
    }
    else {
      BS.Util.hide("${CUSTOM_MAVEN_PATH}_section");
    }

    BS.MultilineProperties.updateVisible();
  };

  window.syncControlState = function() {
    syncMavenSelectionControlState();
    syncUserSettingsControlState();
  };

  window.syncControlState();
</script>
